@@ -93,9 +93,9 @@ renderPlot <- function(expr, width='auto', height='auto', res=72, ...,
 
         # Special case for ggplot objects - need to capture coordmap
         if (inherits(result$value, "ggplot")) {
-          capture.output(coordmap <<- getGgplotCoordmap(result$value, pixelratio))
+          utils::capture.output(coordmap <<- getGgplotCoordmap(result$value, pixelratio))
         } else {
-          capture.output(print(result$value))
+          utils::capture.output(print(result$value))
         }
       }
 
@@ -237,12 +237,12 @@ renderPlot <- function(expr, width='auto', height='auto', res=72, ...,
 # Requires width and height of output image, in pixels.
 # Must be called before the graphics device is closed.
 getPrevPlotCoordmap <- function(width, height) {
-  usrCoords <- par('usr')
+  usrCoords <- graphics::par('usr')
   usrBounds <- usrCoords
-  if (par('xlog')) {
+  if (graphics::par('xlog')) {
     usrBounds[c(1,2)] <- 10 ^ usrBounds[c(1,2)]
   }
-  if (par('ylog')) {
+  if (graphics::par('ylog')) {
     usrBounds[c(3,4)] <- 10 ^ usrBounds[c(3,4)]
   }
 
@@ -257,14 +257,14 @@ getPrevPlotCoordmap <- function(width, height) {
     ),
     # The bounds of the plot area, in DOM pixels
     range = list(
-      left = grconvertX(usrBounds[1], 'user', 'nfc') * width,
-      right = grconvertX(usrBounds[2], 'user', 'nfc') * width,
-      bottom = (1-grconvertY(usrBounds[3], 'user', 'nfc')) * height - 1,
-      top = (1-grconvertY(usrBounds[4], 'user', 'nfc')) * height - 1
+      left = graphics::grconvertX(usrBounds[1], 'user', 'nfc') * width,
+      right = graphics::grconvertX(usrBounds[2], 'user', 'nfc') * width,
+      bottom = (1-graphics::grconvertY(usrBounds[3], 'user', 'nfc')) * height - 1,
+      top = (1-graphics::grconvertY(usrBounds[4], 'user', 'nfc')) * height - 1
     ),
     log = list(
-      x = if (par('xlog')) 10 else NULL,
-      y = if (par('ylog')) 10 else NULL
+      x = if (graphics::par('xlog')) 10 else NULL,
+      y = if (graphics::par('ylog')) 10 else NULL
     ),
     # We can't extract the original variable names from a base graphic.
     # `mapping` is an empty _named_ list, so that it is converted to an object
@@ -278,9 +278,14 @@ getGgplotCoordmap <- function(p, pixelratio) {
   if (!inherits(p, "ggplot"))
     return(NULL)
 
-  # A modified version of print.ggplot which returns the built ggplot object
-  # as well as the gtable grob.
-  print_ggplot <- function(x) {
+  # A modified version of print.ggplot which returns the built ggplot object as
+  # well as the gtable grob. This overrides the ggplot::print.ggplot method, but
+  # only within the context of getGgplotCoordmap. The reason this needs to be an
+  # (pseudo) S3 method is so that, if an object has a class in addition to
+  # ggplot, and there's a print method for that class, that we won't override
+  # that method.
+  # https://github.com/rstudio/shiny/issues/841
+  print.ggplot <- function(x) {
     grid::grid.newpage()
 
     build <- ggplot2::ggplot_build(x)
@@ -294,6 +299,21 @@ getGgplotCoordmap <- function(p, pixelratio) {
     )
   }
 
+  # Given the name of a generic function and an object, return the class name
+  # for the method that would be used on the object.
+  which_method <- function(generic, x) {
+    classes <- class(x)
+    method_names <- paste(generic, classes, sep = ".")
+    idx <- which(method_names %in% utils::methods(generic))
+
+    if (length(idx) == 0)
+      return(NULL)
+
+    # Return name of first class with matching method
+    classes[idx[1]]
+  }
+
+
   # Given a built ggplot object, return x and y domains (data space coords) for
   # each panel.
   find_panel_info <- function(b) {
@@ -519,7 +539,7 @@ getGgplotCoordmap <- function(p, pixelratio) {
     # the image has double size. In the latter case we don't have to scale the
     # numbers down.
     pix_ratio <- 1
-    if (!grepl("^quartz", names(dev.cur()))) {
+    if (!grepl("^quartz", names(grDevices::dev.cur()))) {
       pix_ratio <- pixelratio
     }
 
@@ -536,27 +556,36 @@ getGgplotCoordmap <- function(p, pixelratio) {
     })
   }
 
+  # If print(p) gets dispatched to print.ggplot(p), attempt to extract coordmap.
+  # If dispatched to another method, just print the object and don't attempt to
+  # extract the coordmap. This can happen if there's another print method that
+  # takes precedence.
+  if (identical(which_method("print", p), "ggplot")) {
+    res <- print(p)
 
-  res <- print_ggplot(p)
+    tryCatch({
+      # Get info from built ggplot object
+      info <- find_panel_info(res$build)
 
-  tryCatch({
-    # Get info from built ggplot object
-    info <- find_panel_info(res$build)
+      # Get ranges from gtable - it's possible for this to return more elements than
+      # info, because it calculates positions even for panels that aren't present.
+      # This can happen with facet_wrap.
+      ranges <- find_panel_ranges(res$gtable, pixelratio)
 
-    # Get ranges from gtable - it's possible for this to return more elements than
-    # info, because it calculates positions even for panels that aren't present.
-    # This can happen with facet_wrap.
-    ranges <- find_panel_ranges(res$gtable, pixelratio)
+      for (i in seq_along(info)) {
+        info[[i]]$range <- ranges[[i]]
+      }
 
-    for (i in seq_along(info)) {
-      info[[i]]$range <- ranges[[i]]
-    }
+      return(info)
 
-    return(info)
+    }, error = function(e) {
+      # If there was an error extracting info from the ggplot object, just return
+      # a list with the error message.
+      return(structure(list(), error = e$message))
+    })
 
-  }, error = function(e) {
-    # If there was an error extracting info from the ggplot object, just return
-    # a list with the error message.
-    return(structure(list(), error = e$message))
-  })
+  } else {
+    print(p)
+    return(list())
+  }
 }
